package com.usky.dxtop.controller.web.business;


import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.constant.UserConstants;
import com.usky.dxtop.common.core.domain.ApiResult;
import com.usky.dxtop.common.core.page.CommonPage;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.Company;
import com.usky.dxtop.model.DreOrder;
import com.usky.dxtop.service.CompanyService;
import com.usky.dxtop.service.DreOrderService;
import com.usky.dxtop.service.vo.DreOrderRequest;
import io.swagger.annotations.ApiResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import org.springframework.stereotype.Controller;

/**
 * 餐品订单
 * @author yq
 * @since 2022-08-14
 */
@RestController
@RequestMapping("/dreOrder")
public class DreOrderController {


    @Autowired
    private DreOrderService dreOrderService;

    /**
     * 新增记录
     * @param dreOrder
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public ApiResult<Void> add(@Validated @RequestBody DreOrder dreOrder){
        dreOrderService.add(dreOrder);
        return ApiResult.success();
    }

    /**
     * 修改记录
     */
    @PutMapping
    public ApiResult<Void> edit(@RequestBody DreOrder dreOrder) {
        dreOrderService.update(dreOrder);
        return ApiResult.success();
    }

    /**
     * 分页记录查询
     * @return
     */
    @PostMapping("/page")
    public ApiResult<CommonPage<DreOrder>> page(@RequestBody DreOrderRequest dreOrderRequest)
    {
        return ApiResult.success(dreOrderService.page(dreOrderRequest));
    }


    /**
     * 订单详情导出
     * @param dreOrderRequest
     * @return
     */
    @PostMapping("/exportDetail")
    public ApiResult<String> exportDetail(@RequestBody DreOrderRequest dreOrderRequest){
        return ApiResult.success(dreOrderService.exportDetail(dreOrderRequest));
    }



}

